package com.brmlab.android3;

import org.apache.http.HttpResponse;
import org.apache.http.HttpStatus;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.util.EntityUtils;
import org.json.JSONObject;

import android.app.Activity;
import android.os.AsyncTask;
import android.os.Bundle;
import android.view.Menu;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;

public class MainActivity extends Activity implements OnClickListener {

	private TextView status_label;
	private Button status_button;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		status_label = (TextView) findViewById(R.id.status_label);
		status_button = (Button) findViewById(R.id.get_status);

		status_button.setOnClickListener(this);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.activity_main, menu);
		return true;
	}

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.get_status:
			new FetchStatusTask().execute();
			break;
		}
	}

	private class FetchStatusTask extends AsyncTask<Void, Void, Boolean> {

		@Override
		protected Boolean doInBackground(Void... params) {
			try {
				// create HTTP client object
				HttpClient client = new DefaultHttpClient();
				// most simple way to init GET request
				HttpGet request = new HttpGet(
						"http://nat.brmlab.cz/brmd/brmstatus.json");
				// response will cover whatever response we get
				HttpResponse rp = client.execute(request);
				// we're checking response code to be "200 OK"
				if (rp.getStatusLine().getStatusCode() == HttpStatus.SC_OK) {
					// EntityUtils is helper from HttpClient implementation,
					// will convert request to String
					String results = EntityUtils.toString(rp.getEntity());
					// We parse whole response and create JSON object, Android
					// JSON implementation
					JSONObject whole = new JSONObject(results);
					// We will check, so there won't be exception, if JSON
					// object has desired key
					if (whole.has("open"))
						return whole.getBoolean("open");
				}
			} catch (Exception e) {
				// Printing out exception stacktrace if anything happens
				e.printStackTrace();
			}
			return false;
		}

		@Override
		protected void onPostExecute(Boolean result) {
			super.onPostExecute(result);
			if (status_label != null) {
				if (result) {
					status_label.setText(R.string.status_open);
				} else {
					status_label.setText(R.string.status_closed);
				}
			}
		}
	}

}
